Polygon

Struct Polygon 

pub(crate) struct Polygon {
    points: [Coords3; 12],
    len: usize,
}
Convex polygon of the intersection, kept on the stack: this runs once per element per interface

Fields

points: [Coords3; 12]len: usize

Implementations

Source

impl Polygon

pub(crate) fn from_slice(points: &[Coords3]) -> Self

pub(crate) fn as_slice(&self) -> &[Coords3]

fn push(&mut self, point: Coords3)

pub(crate) fn clip(&self, half_space: &HalfSpace) -> Self

Sutherland-Hodgman clipping of the polygon by one half space, the polygon has to be convex and its vertices ordered. See https://en.wikipedia.org/wiki/Sutherland%E2%80%93Hodgman_algorithm

    keep | drop            keep |
 +-------|---+          +-------+
 |       |  /           |      /
 |  poly | /     =      |     /
 |       |/             |    /
 +-------+              +---+